@@ -10,4 +10,9 @@ const (
 	TemplateFlavorLabelPrefix    = "flavor.template.kubevirt.io/"
 	TemplateWorkloadLabelPrefix  = "workload.template.kubevirt.io/"
 	TemplateDeprecatedAnnotation = "template.kubevirt.io/deprecated"
+
+	TemplateTypeLabelBaseValue = "base"
+
+	CdiApiGroup   = "cdi.kubevirt.io"
+	CdiApiVersion = "v1beta1"
 )
